from setuptools import setup, find_packages


setup(
    name='tongjinlewrapper',
    author = 'Jinle Tong',
    version= '0.0.3',
    author_email= 'lancertong@live.com',
    packages=find_packages(),
    license='apache 3.0'
)